$(document).ready(function(){
	/* The following code is executed once the DOM is loaded */

	make_draggable($('.listBox'));
	
	$('.listBody').sortable({
		items		: 'li',
		axis		: 'xy',				// Only vertical movements allowed
		connectWith	: '.listBody',
//		containment	: 'window',			// Constrained by the window
		update		: function(event, ui){		// The function is called after the todos are rearranged
		
			// The toArray method returns an array with the ids of the todos

			var listClass = "#"+$(ui.item).parent().attr('id')+".listBody";
			var arr = $(listClass).sortable('toArray');
			// Striping the todo- prefix of the ids:
			arr = $.map(arr,function(val,key){
				return val.replace('todo-','');
			});
			
			// Saving with AJAX
			$.get('ajax.php',{action:'rearrange',positions:arr});
		},
		receive		: function(event, ui) {
			//Run this code whenever an item is dragged and dropped into this list
			var itemID = $(ui.item).attr('id').replace('todo-','');
			var listID = $(ui.item).parent().attr('id').replace('List-','');
			$.get("ajax.php",{'action':'changeList','id':itemID,'list_id':listID});
		},
		/* Opera fix: */
		
		stop: function(e,ui) {
			ui.item.css({'top':'0','left':'0'});
		}
	});
	
	// A global variable, holding a jQuery object 
	// containing the current Project, List and ToDO id:
	
	var currentProject;
	var currentList;
	var currentToDo;

	// If any link in the Tab is clicked, assign
	// the project id to the currentProject variable for later use.

	$('.projectTab a').live('click',function(e){
									   
		currentProject = $(this).closest('.projectTab');
		currentProject.data('id',currentProject.attr('id').replace('Project-',''));

		e.preventDefault();
	});

	// If any link in the List is clicked, assign
	// the list item to the currentList variable for later use.

	$('.listBox a').live('click',function(e){
									   
		currentList = $(this).closest('.listBox');
		currentList.data('id',currentList.attr('id').replace('List-',''));

		e.preventDefault();
	});


	// If any link in the todo is clicked, assign
	// the todo item to the currentToDo variable for later use.

	$('.todo a').live('click',function(e){
									   
		currentToDo = $(this).closest('.todo');
		currentToDo.data('id',currentToDo.attr('id').replace('todo-',''));

		e.preventDefault();
	});

	
	// Configuring the delete confirmation dialog
	$("#dialog-confirm").dialog({
		resizable: false,
		width:355,
		height:140,
		modal: true,
		autoOpen:false,
		buttons: {
			'Annuler': function() {
				$(this).dialog('close');
			},
			'Supprimer': function() {
				
				$.get("ajax.php",{"action":"supprimer","id":currentToDo.data('id')},function(msg){
					currentToDo.fadeOut('fast');
				})
				
				$(this).dialog('close');
			}
		}
	});

	// When a double click occurs, just simulate a click on the edit button:
	$('.todo').live('dblclick',function(){
		$(this).find('.editToDo').click();
	});
	
	// Listening for a click on a ToDO delete button:

	$('.todo .deleteToDo').live('click',function(){
//		$("#dialog-confirm").dialog('open');    //uncomment to turn on task delete confirmation

		$.get("ajax.php",{"action":"delete","id":currentToDo.data('id')});
		currentToDo.fadeOut('fast');
	});
	
	//  Listening for key press while editing tasks:

	$('.todo').live('keypress',function(event){
		
//	if (event.keyCode == '13') 	//  Listening for a enter key press to save task:
	//	$(this).find('a.saveChanges').click();

	if (event.keyCode == '27') 	//  Listening for a ESC key press to cancel edit:
		$(this).find('a.discardChanges').click();
	});
	
	// Listening for a click on a edit button
	
	$('.editToDo').live('click',function(){

		var container = currentToDo.find('.text');
		
		if(!currentToDo.data('origText'))
		{
			// Saving the current value of the ToDo so we can
			// restore it later if the user discards the changes:
			
			currentToDo.data('origText',container.text());
		}
		else
		{
			// This will block the edit button if the edit box is already open:
			return false;
		}
		
		$('<input type="text">').val(container.text()).appendTo(container.empty());
		
		// Appending the save and cancel links:
		currentToDo.find('.confirm').show();		
	});
	
	// The cancel ToDo edit link:
	
	$('.confirm a.discardChanges').live('click',function(){
		currentToDo.find('.text')
					.text(currentToDo.data('origText'))
					.end()
					.removeData('origText');
		currentToDo.find('.confirm').hide();		
	});
	
	// The save ToDO changes link:
	
	$('.confirm a.saveChanges').live('click',function(){
		var text = currentToDo.find("input[type=text]").val();
		
		$.get("ajax.php",{'action':'edit','id':currentToDo.data('id'),'text':text});
		
		currentToDo.removeData('origText')
					.find(".text")
					.text(text);
		currentToDo.find('.confirm').hide();		
	});
	
	
	// The Add New ToDo button:
	
	var timestamp=0;
	$('a.newToDo').live('click',function(e){
		
		// Only one todo per second is allowed:
		if((new Date()).getTime() - timestamp<1000) return false;
		
		// if the listBody was collapsed, expand it and save setting to database
		currentList.find('.listBody').css("display",function(value){

				if (value = 'hidden') {

					currentList.find('.listBody').show();

					currentList.data('id',currentList.attr('id').replace('List-',''));

					$.get("ajax.php",{"action":"listExpanded","id":currentList.data('id')});
					
				}
		});
		
		var listID = TaskListID.replace('List-','');
		
		$.get("ajax.php",{'action':'new','list_id':listID,'text':'Double cliquer pour &eacute;diter.','rand':Math.random()},function(msg){

			// Appending the new todo and fading it into view:
			$(msg).hide().appendTo('#'+TaskListID+'.listBody').fadeIn();
		});

		// Updating the timestamp:
		timestamp = (new Date()).getTime();
		
		e.preventDefault();
	});

	// Configuring the delete confirmation dialog
	$("#dialog-confirm-delete-list").dialog({
		resizable: false,
		width:355,
		height:160,
		modal: true,
		autoOpen:false,
		buttons: {
			'Annuler': function() {
				$(this).dialog('close');
			},
			'Supprimer': function() {
				
				$.get("ajax.php",{"action":"deleteList","id":currentList.data('id')},function(msg){
					currentList.fadeOut('fast');
				})
				
				$(this).dialog('close');
			}
		}
	});

// when mouse over ToDo items show the edit and delete options
$('.todo').live('mouseover mouseout', function(event) {
  if (event.type == 'mouseover') {
    $(this).find('.actionsToDo').show();
  } else {
    $(this).find('.actionsToDo').hide(); 
  }
});


// * * * * * * * * * * * * * * *  List specific code starts here * * * * * * * * * * * * * * * * * * * * 


	// Add a new ToDo List
	
$('#newList').live('click',function(e){

	currentProject = $(this).closest('.project');
	currentProjectID = currentProject.data('id',currentProject.attr('id'));
	currentProjectID = currentProjectID.data('id');
	project_id = currentProject.data('id',currentProject.attr('id').replace('tabs-',''));
	project_id = project_id.data('id');

		$.get("ajax.php",{'action':'newList','name':'Nouvelle Liste','rand':Math.random(),'project_id':project_id},function(msg){

			// Appending the new todo and fading it into view:
			$(msg).hide().appendTo('#'+currentProjectID).draggable({
		handle: '.listName',
		start:	function(e,ui){ ui.helper.css('z-index',++zIndex); },
		stop:	function(e,ui){

			/* Sending the positon of the list to ajax.php  */

			$.get("ajax.php",{
								"action":"listPosition",
								"x"		: ui.position.left,
								"y"		: ui.position.top,
								"z"		: zIndex,
								"id"	: parseInt(ui.helper.find('span.data').html())
			});
		}}).sortable({
		items		: 'li',
		axis		: 'xy',				// Only vertical movements allowed
		connectWith	: '.listBody',
//		containment	: 'window',			// Constrained by the window
		update		: function(event, ui){		// The function is called after the todos are rearranged
		
			// The toArray method returns an array with the ids of the todos

			var listClass = "#"+$(ui.item).parent().attr('id')+".listBody";
			var arr = $(listClass).sortable('toArray');
			// Striping the todo- prefix of the ids:
			arr = $.map(arr,function(val,key){
				return val.replace('todo-','');
			});
			
			// Saving with AJAX
			$.get('ajax.php',{action:'rearrange',positions:arr});
		},
		receive		: function(event, ui) {
			//Run this code whenever an item is dragged and dropped into this list
			var itemID = $(ui.item).attr('id').replace('todo-','');
			var listID = $(ui.item).parent().attr('id').replace('List-','');
			$.get("ajax.php",{'action':'changeList','id':itemID,'list_id':listID});
		},
		/* Opera fix: */
		
		stop: function(e,ui) {
			ui.item.css({'top':'0','left':'0'});
		}
		
	}).fadeIn();
		});
		
		e.preventDefault();
	});

	// Listening for a click on the List name edit button
	
	$('.listTitle a.editList').live('click',function(){
		var container = currentList.find('.listName');

		if(!currentList.data('origText'))
		{
			// Saving the current value of the ToDo so we can
			// restore it later if the user discards the changes:
			
			currentList.data('origText',container.text());
		}
		else
		{
			// This will block the edit button if the edit box is already open:
			return false;
		}
		
		$('<input type="text">').val(container.text()).appendTo(container.empty());
		
		// Appending the save and cancel links:
		currentList.find('.confirmList').show();
		
	});

	// The cancel List edit link:
	
	$('.listTitle a.discardChanges').live('click',function(){
		currentList.find('.listName')
					.text(currentList.data('origText'))
					.end()
					.removeData('origText');
		currentList.find('.confirmList').hide();
	});
	
	// The save List changes link:
	
	$('.listTitle a.saveChanges').live('click',function(){
		var text = currentList.find("input[type=text]").val();

		$.get("ajax.php",{'action':'editList','id':currentList.data('id'),'name':text});
		
		currentList.removeData('origText')
					.find(".listName")
					.text(text);
		currentList.find('.confirmList').hide();
	});

	//  Listening for key press while editing lists:

	$('.listTitle').live('keypress',function(event){
		
//	if (event.keyCode == '13') 	//  Listening for a enter key press to save task:
//		$(this).find('a.saveChanges').click();

	if (event.keyCode == '27') 	//  Listening for a ESC key press to cancel edit:
		$(this).find('a.discardChanges').click();
	});

	// Listening for a click on a List delete button:

	$('.listTitle a.deleteList').live('click',function(){
		$("#dialog-confirm-delete-list").dialog('open');
	});

	// Configuring the delete confirmation dialog
	$("#dialog-confirm-delete-list").dialog({
		resizable: false,
		width:270,
		height:120,
		modal: true,
		autoOpen:false,
		buttons: {
			'Annuler': function() {
				$(this).dialog('close');
			},
			'Supprimer': function() {
				
				$.get("ajax.php",{"action":"deleteList","id":currentList.data('id')},function(msg){
					currentList.fadeOut('fast');
				})
				
				$(this).dialog('close');
			}
		}
	});

// when mouse over List title show the edit and delete options
$('.listTitle').live('mouseover mouseout', function(event) {
  if (event.type == 'mouseover') {
    $(this).find('.actionsList').show();
  } else {
    $(this).find('.actionsList').hide(); 
  }
});

// Toggle the expand and collapse of a List
$('.listHead').live('click',function(e){

	$(this).next('.listBody').slideToggle(600);
	


	currentList = $(this).closest('.listBox');
	currentList.data('id',currentList.attr('id').replace('List-',''));
	var listID = currentList.data('id');

	$.get("ajax.php",{"action":"listToggleExpanded","id":currentList.data('id')});

	var currentImage = $('img#List-'+listID+'.collapse').attr("src");

		if (currentImage == './img/collapse.png') {

			$('img#List-'+listID+'.collapse').attr("src","./img/expand.png");
		}
		
		else {
			$('img#List-'+listID+'.collapse').attr("src","./img/collapse.png");
		}

});


// * * * * * * * * * * * * * * *  List specific code ends here * * * * * * * * * * * * * * * * * * * * 




// * * * * * * * * * * * * * * *  Tab specific code starts here * * * * * * * * * * * * * * * * * * * * 

var $tabs = $("#tabs").tabs();

var $tab_items = $($tabs).droppable({
	accept: ".listBox",
	hoverClass: "ui-state-hover",
	drop: function(ev, ui) {
		var $item = $(this);
	
		var $list = $($item.find('a').attr('href')).find('.project');

		ui.draggable.hide('slow', function() {
			$tabs.tabs('select', $tab_items.index($item));
			$(this).appendTo($list).show('slow');
		});
	}
}).find(".ui-tabs-nav").sortable({
		axis		:'x',
		update		: function(event, ui){		// The function is called after the todos are rearranged
				
					// The toArray method returns an array with the ids of the todos
		
					var arr = $("#tabRow").sortable('toArray');
					// Striping the Project- prefix of the ids:
					arr = $.map(arr,function(val,key){
						return val.replace('Project-','');
					});
					
					// Saving with AJAX
					$.get('ajax.php',{action:'rearrangeProjects',positions:arr});
				}
		});

	// Add a new Tab
	
$('#newTab').live('click',function(e){

	$.get("ajax.php",{'action':'newProject','name':'Nouvel onglet'},function(msg){

		// Appending the new todo and fading it into view:
		tabBody = '<div id="tabs-'+msg+'" class="project">'+
			'		<a id="newList" class="newList" href=""><abbr title="Nouvelle Liste"><img src="./img/new-list.png" width="28" height="28"></abbr></a>'+
			'	</div>';

		$(tabBody).hide().appendTo('#tabs').fadeIn();
		//$( "#tabs" ).tabs( "option", "panelTemplate", '		<li div id="Project-'+msg+'" class="projectTab"></li>' );
		$("#tabs").tabs("option", "tabTemplate", '		<li div id="Project-'+msg+'" class="projectTab">'+	 
			'			<div class="projectTitle">'+
			 '				<a href="#tabs-'+msg+'" ><div class="projectName">Nouvel onglet</div></a>'+
			 '			</div>'+
			
			 '			<div class="confirmTab">'+
			 '				<a class="saveChanges" href=""><abbr title="Save"><img src="./img/save.png" width="16" height="16"></abbr></a>'+
			 '				<a class="discardChanges" href=""><abbr title="Cancel"><img src="./img/cancel.png" width="16" height="16"></abbr></a>'+
			 '			</div>'+
			
			 '			<div class="actionsTab">'+
			 '				<a href="" class="editTab"><abbr title="Edit Tab"><img src="./img/edit.png" width="16" height="16" /></abbr></a>'+
			 '				<a href="" class="deleteTab"><abbr title="Delete Tab"><img src="./img/delete.png" width="16" height="16" /></abbr></a>'+
			 '			</div>'+
			 '		</li>'
		);
		
		$("#tabs").tabs("add","#tabs-"+msg,"Nouvel onglet");

	});

		e.preventDefault();

	});

// when mouse over List title show the edit and delete options

$('.projectTab').live('mouseover mouseout', function(event) {
  if (event.type == 'mouseover') {
    $(this).find('.actionsTab').show();
  } else {
    $(this).find('.actionsTab').hide(); 
  }
});

	// Listening for a click on the Tab name edit button
	
	$('.projectTab a.editTab').live('click',function(){
		var container = currentProject.find('.projectName');

		if(!currentProject.data('origText'))
		{
			// Saving the current value of the ToDo so we can
			// restore it later if the user discards the changes:
			
			currentProject.data('origText',container.text());
		}
		else
		{
			// This will block the edit button if the edit box is already open:
			return false;
		}
		
		$('<input type="text">').val(container.text()).appendTo(container.empty());
		
		// Appending the save and cancel links:
		currentProject.find('.confirmTab').show();
		
	});

	// The cancel Tab edit link:
	
	$('.confirmTab a.discardChanges').live('click',function(){
		currentProject.find('.projectName')
					.text(currentProject.data('origText'))
					.end()
					.removeData('origText');

		currentProject.find('.confirmTab').hide();
	});
	
	// The save Tab name change:
	
	$('.confirmTab a.saveChanges').live('click',function(){
		var text = currentProject.find("input[type=text]").val();

		$.get("ajax.php",{'action':'editProject','id':currentProject.data('id'),'name':text});
		
		currentProject.removeData('origText')
					.find(".projectName")
					.text(text);

		currentProject.find('.confirmTab').hide();
	});

	//  Listening for key press while editing Tab name:

	$('.projectName').live('keypress',function(event){
//	if (event.keyCode == '13') 	//  Listening for a enter key press to save Tab Name:
//		currentProject.find('a.saveChanges').click();

	if (event.keyCode == '27') 	//  Listening for a ESC key press to cancel Tab edit:
		currentProject.find('a.discardChanges').click();
	});

	// Listening for a click on a Tab delete button:

	$('.actionsTab a.deleteTab').live('click',function(){
		$("#dialog-confirm-delete-project").dialog('open');
	});

	// Configuring the Tab delete confirmation dialog
	
	$("#dialog-confirm-delete-project").dialog({
		resizable: false,
		width:370,
		height:120,
		modal: true,
		autoOpen:false,
		buttons: {
			'Annuler': function() {
				$(this).dialog('close');
			},
			'Supprimer': function() {
				
				$.get("ajax.php",{"action":"deleteProject","id":currentProject.data('id')},function(msg){
					currentProject.fadeOut('fast');
					$("#tabs").tabs("select",0)
				})

				$(this).dialog('close');
			}
		}
	});


// * * * * * * * * * * * * * * *  Tab specific code ends here * * * * * * * * * * * * * * * * * * * * 


}); // Closing $(document).ready()




// * * * * * * * * * * * * * * *  Functions here * * * * * * * * * * * * * * * * * * * * 


var zIndex = 0;
var TaskListID;

function make_draggable(element)
{
	/* Element is a jquery object: */
	
	element.draggable({
		handle: '.listName',
		start:	function(e,ui){ ui.helper.css('z-index',++zIndex); },
		stop:	function(e,ui){

			/* Sending the z-index and positon of the list to update_position.php via AJAX GET: */

			$.get("ajax.php",{
								"action":"listPosition",
								"x"		: ui.position.left,
								"y"		: ui.position.top,
								"z"		: zIndex,
								"id"	: parseInt(ui.helper.find('span.data').html())
			});
		}
	});
}

function myCallback(caller)
{
  // Change "nodeName" to "id" if that's what you want
  TaskListID = caller.parentNode.id;
}
